#include <LedControl.h>
#include <Adafruit_APDS9960.h>
#define DIN_PIN 4
#define CLK_PIN 2
#define LOAD_PIN 3
#define ARROW_UP 0
#define ARROW_DOWN 1
#define ARROW_LEFT 2
#define ARROW_RIGHT 3

LedControl lc = LedControl(DIN_PIN, CLK_PIN, LOAD_PIN, 1);
Adafruit_APDS9960 apds;

const uint64_t ARROWS[] = {
  0x1c1c1c1c7f3e1c08, // ^
  0x081c3e7f1c1c1c1c, // v
  0x00080cfefffe0c08, // <
  0x0010307fff7f3010, // >
};
const int ARROWS_SIZE = sizeof(ARROWS) / 8;

void setup() {
  lc.shutdown(0, false);
  lc.setIntensity(0, 7);
  lc.clearDisplay(0);
  apds.begin();
  apds.enableProximity(true);
  apds.enableGesture(true);
}

void loop() {
  int gesture = apds.readGesture();
  if (gesture) {
    updateDisplay(gesture);
  }
}

void updateDisplay(int gesture) {
  switch (gesture) {
    case APDS9960_UP:
      displayImage(ARROWS[ARROW_DOWN]);
      break;
      
    case APDS9960_DOWN:
      displayImage(ARROWS[ARROW_UP]);
      break;
      
    case APDS9960_LEFT:
      displayImage(ARROWS[ARROW_RIGHT]);
      break;
      
    case APDS9960_RIGHT:
      displayImage(ARROWS[ARROW_LEFT]);
      break;
  }
}

void displayImage(uint64_t image) {
  for (int i = 0; i < 8; i++) {
    byte row = (image >> i * 8) & 0xFF;
    for (int j = 0; j < 8; j++) {
      lc.setLed(0, i, j, bitRead(row, j));
    }
  }
}
